@@ -122,6 +122,44 @@ void IndicatorTypeEntry::onValueSelected(int index) {
 	}
 }
 
+class IndicatorButtonEntry : public ZLComboOptionEntry {
+
+public:
+	IndicatorButtonEntry(const ZLResource &resource, ZLIntegerRangeOption &buttonOption);
+	const std::string &initialValue() const;
+
+private:
+	const std::vector<std::string> &values() const;
+	void onAccept(const std::string &value);
+
+private:
+	std::vector<std::string> myValues;
+	ZLIntegerRangeOption &myOption;
+};
+
+IndicatorButtonEntry::IndicatorButtonEntry(const ZLResource &resource, ZLIntegerRangeOption &buttonOption) : myOption(buttonOption) {
+	myValues.push_back(resource["none"].value());
+	myValues.push_back(resource["fullScreen"].value());
+	myValues.push_back(resource["popupMenu"].value());
+}
+
+const std::string &IndicatorButtonEntry::initialValue() const {
+	return myValues[myOption.value()];
+}
+
+const std::vector<std::string> &IndicatorButtonEntry::values() const {
+	return myValues;
+}
+
+void IndicatorButtonEntry::onAccept(const std::string &value) {
+	for (size_t index = 0; index != myValues.size(); ++index) {
+		if (myValues[index] == value) {
+			myOption.setValue(index);
+			break;
+		}
+	}
+}
+
 void OptionsDialog::createIndicatorTab() {
 	ZLDialogContent &indicatorTab = myDialog->createTab(ZLResourceKey("Indicator"));
 	FBIndicatorStyle &indicatorInfo = FBView::commonIndicatorInfo();
@@ -148,10 +186,11 @@ void OptionsDialog::createIndicatorTab() {
 	indicatorTab.addOption(ZLResourceKey("time"), showTimeEntry);
 	indicatorTypeEntry->addDependentEntry(showTimeEntry);
 
-	StateOptionEntry *showFSToggleEntry =
-		new StateOptionEntry(indicatorInfo.ShowFSToggleOption);
-	indicatorTab.addOption(ZLResourceKey("fullScreen"), showFSToggleEntry);
-	indicatorTypeEntry->addDependentEntry(showFSToggleEntry);
+	static ZLResourceKey buttonKey("button");
+	IndicatorButtonEntry *indicatorButtonEntry =
+		new IndicatorButtonEntry(indicatorTab.resource(buttonKey), indicatorInfo.ButtonOption);
+	indicatorTab.addOption(buttonKey, indicatorButtonEntry);
+	indicatorTypeEntry->addDependentEntry(indicatorButtonEntry);
 
 	SpecialFontSizeEntry *fontSizeEntry =
 		new SpecialFontSizeEntry(indicatorInfo.FontSizeOption, 2, *showTextPositionEntry, *showTimeEntry);
